Sybase — SQLAlchemy 1.0 Documentation

Release: 1.0.0b1 | Release Date: March 13, 2015

# SQLAlchemy 1.0 Documentation

# Sybase

Support for the Sybase database.

## DBAPI Support

The following dialect/DBAPI options are available. Please refer to individual DBAPI sections for connect information.

- Python-Sybase
- PyODBC
- mxODBC

Note

The Sybase dialect functions on current SQLAlchemy versions but is not regularly tested, and may have many issues and caveats not currently handled.

## python-sybase

Support for the Sybase database via the Python-Sybase driver.

### DBAPI

Documentation and download information (if applicable) for Python-Sybase is available at: http://python-sybase.sourceforge.net/

### Connecting

Connect String:

    sybase+pysybase://<username>:<password>@<dsn>/[database name]

### Unicode Support

The python-sybase driver does not appear to support non-ASCII strings of any kind at this time.

## pyodbc

Support for the Sybase database via the PyODBC driver.

### DBAPI

Documentation and download information (if applicable) for PyODBC is available at: http://pypi.python.org/pypi/pyodbc/

### Connecting

Connect String:

    sybase+pyodbc://<username>:<password>@<dsnname>[/<database>]

### Unicode Support

The pyodbc driver currently supports usage of these Sybase types with Unicode or multibyte strings:

    CHAR
    NCHAR
    NVARCHAR
    TEXT
    VARCHAR

Currently not supported are:

    UNICHAR
    UNITEXT
    UNIVARCHAR

## mxodbc

Support for the Sybase database via the mxODBC driver.

### DBAPI

Documentation and download information (if applicable) for mxODBC is available at: http://www.egenix.com/

### Connecting

Connect String:

    sybase+mxodbc://<username>:<password>@<dsnname>

Note

This dialect is a stub only and is likely non functional at this time.